Package: magick
Type: Package
Title: Advanced Graphics and Image-Processing in R
Version: 2.9.1
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroenooms@gmail.com",
    comment = c(ORCID = "0000-0002-4035-0289"))
Description: Bindings to 'ImageMagick': the most comprehensive open-source image
    processing library available. Supports many common formats (png, jpeg, tiff,
    pdf, etc) and manipulations (rotate, scale, crop, trim, flip, blur, etc).
    All operations are vectorized via the Magick++ STL meaning they operate either
    on a single frame or a series of frames for working with layers, collages,
    or animation. In RStudio images are automatically previewed when printed to
    the console, resulting in an interactive editing environment. Also includes
    a graphics device for creating drawing onto images using pixel coordinates.
License: MIT + file LICENSE
URL: https://docs.ropensci.org/magick/
        https://ropensci.r-universe.dev/magick
BugReports: https://github.com/ropensci/magick/issues
SystemRequirements: ImageMagick++: ImageMagick-c++-devel (rpm) or
        libmagick++-dev (deb)
VignetteBuilder: knitr
Depends: R (>= 4.1.0)
Imports: Rcpp (>= 0.12.12), magrittr, curl
LinkingTo: Rcpp
Suggests: av, spelling, jsonlite, methods, knitr, rmarkdown, rsvg,
        webp, pdftools, ggplot2, gapminder, IRdisplay, tesseract,
        gifski
Encoding: UTF-8
RoxygenNote: 7.3.3
Language: en-US
NeedsCompilation: yes
Packaged: 2026-02-28 14:23:36 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (ORCID: <https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2026-02-28 15:40:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 16:03:37 UTC; unix
Archs: magick.so.dSYM
