Package: magick
Type: Package
Title: Advanced Graphics and Image-Processing in R
Version: 2.7.5
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroen@berkeley.edu",
    comment = c(ORCID = "0000-0002-4035-0289"))
Description: Bindings to 'ImageMagick': the most comprehensive open-source image
    processing library available. Supports many common formats (png, jpeg, tiff,
    pdf, etc) and manipulations (rotate, scale, crop, trim, flip, blur, etc).
    All operations are vectorized via the Magick++ STL meaning they operate either
    on a single frame or a series of frames for working with layers, collages,
    or animation. In RStudio images are automatically previewed when printed to
    the console, resulting in an interactive editing environment. The latest 
    version of the package includes a native graphics device for creating 
    in-memory graphics or drawing onto images using pixel coordinates.
License: MIT + file LICENSE
URL: https://docs.ropensci.org/magick/ (website)
        https://github.com/ropensci/magick (devel)
BugReports: https://github.com/ropensci/magick/issues
SystemRequirements: ImageMagick++: ImageMagick-c++-devel (rpm) or
        libmagick++-dev (deb)
VignetteBuilder: knitr
Imports: Rcpp (>= 0.12.12), magrittr, curl
LinkingTo: Rcpp
Suggests: av (>= 0.3), spelling, jsonlite, methods, knitr, rmarkdown,
        rsvg, webp, pdftools, ggplot2, gapminder, IRdisplay, tesseract
        (>= 2.0), gifski
Encoding: UTF-8
RoxygenNote: 7.2.3
Language: en-US
NeedsCompilation: yes
Packaged: 2023-08-07 11:37:02 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (<https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroen@berkeley.edu>
Repository: CRAN
Date/Publication: 2023-08-07 12:50:05 UTC
