# Generated by roxygen2: do not edit by hand

S3method("[","magick-image")
S3method("[<-","magick-image")
S3method("[[","magick-image")
S3method("[[<-","magick-image")
S3method(as.double,bitmap)
S3method(as.integer,"magick-image")
S3method(as.integer,bitmap)
S3method(as.list,"magick-image")
S3method(as.raster,"magick-image")
S3method(c,"magick-image")
S3method(length,"magick-image")
S3method(plot,"magick-image")
S3method(print,"magick-image")
S3method(print,bitmap)
S3method(rep,"magick-image")
S3method(rev,"magick-image")
export("%>%")
export(as_EBImage)
export(autoviewer_disable)
export(autoviewer_enable)
export(channel_types)
export(coder_info)
export(colorspace_types)
export(compose_types)
export(compress_types)
export(decoration_types)
export(demo_image)
export(dispose_types)
export(distort_types)
export(dump_option_info)
export(filter_types)
export(geometry_area)
export(geometry_point)
export(geometry_size_percent)
export(geometry_size_pixels)
export(granite)
export(gravity_types)
export(image_animate)
export(image_annotate)
export(image_append)
export(image_apply)
export(image_attributes)
export(image_average)
export(image_background)
export(image_blank)
export(image_blur)
export(image_border)
export(image_browse)
export(image_canny)
export(image_capture)
export(image_channel)
export(image_charcoal)
export(image_chop)
export(image_coalesce)
export(image_colorize)
export(image_combine)
export(image_comment)
export(image_compare)
export(image_compare_dist)
export(image_composite)
export(image_connect)
export(image_contrast)
export(image_convert)
export(image_convolve)
export(image_crop)
export(image_data)
export(image_deskew)
export(image_deskew_angle)
export(image_despeckle)
export(image_destroy)
export(image_device)
export(image_display)
export(image_distort)
export(image_draw)
export(image_edge)
export(image_emboss)
export(image_enhance)
export(image_equalize)
export(image_extent)
export(image_fft)
export(image_fill)
export(image_flatten)
export(image_flip)
export(image_flop)
export(image_frame)
export(image_fuzzycmeans)
export(image_fx)
export(image_fx_sequence)
export(image_get_artifact)
export(image_ggplot)
export(image_graph)
export(image_hough_draw)
export(image_hough_txt)
export(image_implode)
export(image_info)
export(image_join)
export(image_lat)
export(image_level)
export(image_map)
export(image_median)
export(image_modulate)
export(image_montage)
export(image_morph)
export(image_morphology)
export(image_mosaic)
export(image_motion_blur)
export(image_negate)
export(image_noise)
export(image_normalize)
export(image_ocr)
export(image_ocr_data)
export(image_oilpaint)
export(image_ordered_dither)
export(image_orient)
export(image_page)
export(image_quantize)
export(image_raster)
export(image_read)
export(image_read_pdf)
export(image_read_svg)
export(image_read_video)
export(image_reducenoise)
export(image_repage)
export(image_resize)
export(image_rotate)
export(image_sample)
export(image_scale)
export(image_separate)
export(image_set_defines)
export(image_shade)
export(image_shadow)
export(image_shadow_mask)
export(image_shear)
export(image_split)
export(image_strip)
export(image_threshold)
export(image_transparent)
export(image_trim)
export(image_types)
export(image_virtual_pixel)
export(image_write)
export(image_write_gif)
export(image_write_video)
export(kernel_types)
export(logo)
export(magick_config)
export(magick_fonts)
export(magick_options)
export(magick_set_seed)
export(metric_types)
export(morphology_types)
export(noise_types)
export(option_types)
export(orientation_types)
export(rose)
export(style_types)
export(virtual_pixel_methods)
export(wizard)
importFrom(Rcpp,sourceCpp)
importFrom(grDevices,as.raster)
importFrom(graphics,plot)
importFrom(magrittr,"%>%")
useDynLib(magick)
