# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

magick_image_animate <- function(input, delay, iter, method, optimize) {
    .Call('_magick_magick_image_animate', PACKAGE = 'magick', input, delay, iter, method, optimize)
}

magick_image_coalesce <- function(input) {
    .Call('_magick_magick_image_coalesce', PACKAGE = 'magick', input)
}

magick_image_morph <- function(image, frames) {
    .Call('_magick_magick_image_morph', PACKAGE = 'magick', image, frames)
}

magick_image_mosaic <- function(input, composite) {
    .Call('_magick_magick_image_mosaic', PACKAGE = 'magick', input, composite)
}

magick_image_flatten <- function(input, composite) {
    .Call('_magick_magick_image_flatten', PACKAGE = 'magick', input, composite)
}

magick_image_average <- function(image) {
    .Call('_magick_magick_image_average', PACKAGE = 'magick', image)
}

magick_image_append <- function(image, stack) {
    .Call('_magick_magick_image_append', PACKAGE = 'magick', image, stack)
}

magick_attr_comment <- function(input, set) {
    .Call('_magick_magick_attr_comment', PACKAGE = 'magick', input, set)
}

magick_attr_text_antialias <- function(input, set) {
    .Call('_magick_magick_attr_text_antialias', PACKAGE = 'magick', input, set)
}

magick_attr_stroke_antialias <- function(input, set) {
    .Call('_magick_magick_attr_stroke_antialias', PACKAGE = 'magick', input, set)
}

magick_attr_animationdelay <- function(input, delay) {
    .Call('_magick_magick_attr_animationdelay', PACKAGE = 'magick', input, delay)
}

magick_attr_backgroundcolor <- function(input, color) {
    .Call('_magick_magick_attr_backgroundcolor', PACKAGE = 'magick', input, color)
}

magick_attr_boxcolor <- function(input, color) {
    .Call('_magick_magick_attr_boxcolor', PACKAGE = 'magick', input, color)
}

magick_attr_fillcolor <- function(input, color) {
    .Call('_magick_magick_attr_fillcolor', PACKAGE = 'magick', input, color)
}

magick_attr_font <- function(input, font) {
    .Call('_magick_magick_attr_font', PACKAGE = 'magick', input, font)
}

magick_attr_fontsize <- function(input, pointsize) {
    .Call('_magick_magick_attr_fontsize', PACKAGE = 'magick', input, pointsize)
}

magick_attr_label <- function(input, label) {
    .Call('_magick_magick_attr_label', PACKAGE = 'magick', input, label)
}

magick_attr_format <- function(input, format) {
    .Call('_magick_magick_attr_format', PACKAGE = 'magick', input, format)
}

magick_attr_quality <- function(input, quality) {
    .Call('_magick_magick_attr_quality', PACKAGE = 'magick', input, quality)
}

magick_attr_quantize <- function(input, numcolors) {
    .Call('_magick_magick_attr_quantize', PACKAGE = 'magick', input, numcolors)
}

magick_attr_density <- function(input, density) {
    .Call('_magick_magick_attr_density', PACKAGE = 'magick', input, density)
}

magick_image_info <- function(input) {
    .Call('_magick_magick_image_info', PACKAGE = 'magick', input)
}

magick_image_as_raster <- function(data) {
    .Call('_magick_magick_image_as_raster', PACKAGE = 'magick', data)
}

magick_threads <- function(i = 0L) {
    .Call('_magick_magick_threads', PACKAGE = 'magick', i)
}

magick_image_dead <- function(image) {
    .Call('_magick_magick_image_dead', PACKAGE = 'magick', image)
}

magick_image_length <- function(image) {
    .Call('_magick_magick_image_length', PACKAGE = 'magick', image)
}

create <- function(len) {
    .Call('_magick_create', PACKAGE = 'magick', len)
}

magick_image_blank <- function(width, height, color, pseudo_image, options) {
    .Call('_magick_magick_image_blank', PACKAGE = 'magick', width, height, color, pseudo_image, options)
}

copy <- function(image) {
    .Call('_magick_copy', PACKAGE = 'magick', image)
}

magick_image_rev <- function(input) {
    .Call('_magick_magick_image_rev', PACKAGE = 'magick', input)
}

magick_image_join <- function(input) {
    .Call('_magick_magick_image_join', PACKAGE = 'magick', input)
}

magick_image_subset <- function(image, index) {
    .Call('_magick_magick_image_subset', PACKAGE = 'magick', image, index)
}

magick_image_replace <- function(image, index, value) {
    .Call('_magick_magick_image_replace', PACKAGE = 'magick', image, index, value)
}

magick_image_copy <- function(image, add) {
    .Call('_magick_magick_image_copy', PACKAGE = 'magick', image, add)
}

magick_image_destroy <- function(image) {
    invisible(.Call('_magick_magick_image_destroy', PACKAGE = 'magick', image))
}

autobrewed <- function() {
    .Call('_magick_autobrewed', PACKAGE = 'magick')
}

magick_resource_limits <- function() {
    .Call('_magick_magick_resource_limits', PACKAGE = 'magick')
}

magick_image_contrast <- function(input, sharpen) {
    .Call('_magick_magick_image_contrast', PACKAGE = 'magick', input, sharpen)
}

magick_image_normalize <- function(input) {
    .Call('_magick_magick_image_normalize', PACKAGE = 'magick', input)
}

magick_image_modulate <- function(input, brightness, saturation, hue) {
    .Call('_magick_magick_image_modulate', PACKAGE = 'magick', input, brightness, saturation, hue)
}

magick_image_map <- function(input, map_image, dither) {
    .Call('_magick_magick_image_map', PACKAGE = 'magick', input, map_image, dither)
}

magick_image_channel <- function(input, channel) {
    .Call('_magick_magick_image_channel', PACKAGE = 'magick', input, channel)
}

magick_image_colorize <- function(input, opacity, color) {
    .Call('_magick_magick_image_colorize', PACKAGE = 'magick', input, opacity, color)
}

magick_image_enhance <- function(input) {
    .Call('_magick_magick_image_enhance', PACKAGE = 'magick', input)
}

magick_image_equalize <- function(input) {
    .Call('_magick_magick_image_equalize', PACKAGE = 'magick', input)
}

magick_image_median <- function(input, radius) {
    .Call('_magick_magick_image_median', PACKAGE = 'magick', input, radius)
}

magick_image_quantize <- function(input, max, space, dither, depth) {
    .Call('_magick_magick_image_quantize', PACKAGE = 'magick', input, max, space, dither, depth)
}

magick_image_ordered_dither <- function(input, threshold_map) {
    .Call('_magick_magick_image_ordered_dither', PACKAGE = 'magick', input, threshold_map)
}

magick_image_transparent <- function(input, color, fuzz_percent) {
    .Call('_magick_magick_image_transparent', PACKAGE = 'magick', input, color, fuzz_percent)
}

magick_image_background <- function(input, color) {
    .Call('_magick_magick_image_background', PACKAGE = 'magick', input, color)
}

magick_image_lat <- function(input, geomstr) {
    .Call('_magick_magick_image_lat', PACKAGE = 'magick', input, geomstr)
}

magick_image_threshold_black <- function(input, threshold, channel) {
    .Call('_magick_magick_image_threshold_black', PACKAGE = 'magick', input, threshold, channel)
}

magick_image_threshold_white <- function(input, threshold, channel) {
    .Call('_magick_magick_image_threshold_white', PACKAGE = 'magick', input, threshold, channel)
}

magick_image_level <- function(input, black_pct, white_pct, mid_point, channel) {
    .Call('_magick_magick_image_level', PACKAGE = 'magick', input, black_pct, white_pct, mid_point, channel)
}

magick_image_composite <- function(input, composite_image, offset, gravity, composite, args) {
    .Call('_magick_magick_image_composite', PACKAGE = 'magick', input, composite_image, offset, gravity, composite, args)
}

magick_image_border <- function(input, color, geometry, composite) {
    .Call('_magick_magick_image_border', PACKAGE = 'magick', input, color, geometry, composite)
}

magick_image_frame <- function(input, color, geometry) {
    .Call('_magick_magick_image_frame', PACKAGE = 'magick', input, color, geometry)
}

magick_image_shadow_mask <- function(input, geomstr) {
    .Call('_magick_magick_image_shadow_mask', PACKAGE = 'magick', input, geomstr)
}

magick_image_shade <- function(input, azimuth = 30, elevation = 30, color = FALSE) {
    .Call('_magick_magick_image_shade', PACKAGE = 'magick', input, azimuth, elevation, color)
}

magick_image_crop <- function(input, geometry, gravity, repage) {
    .Call('_magick_magick_image_crop', PACKAGE = 'magick', input, geometry, gravity, repage)
}

magick_image_extent <- function(input, geometry, gravity, color) {
    .Call('_magick_magick_image_extent', PACKAGE = 'magick', input, geometry, gravity, color)
}

magick_image_artifact <- function(input, name) {
    .Call('_magick_magick_image_artifact', PACKAGE = 'magick', input, name)
}

magick_coder_info <- function(format) {
    .Call('_magick_magick_coder_info', PACKAGE = 'magick', format)
}

magick_config_internal <- function() {
    .Call('_magick_magick_config_internal', PACKAGE = 'magick')
}

magick_image_fx <- function(input, expression, channel) {
    .Call('_magick_magick_image_fx', PACKAGE = 'magick', input, expression, channel)
}

magick_image_fx_sequence <- function(input, expr) {
    .Call('_magick_magick_image_fx_sequence', PACKAGE = 'magick', input, expr)
}

magick_image_morphology <- function(input, method, kernel, iter, opt_names, opt_values) {
    .Call('_magick_magick_image_morphology', PACKAGE = 'magick', input, method, kernel, iter, opt_names, opt_values)
}

magick_image_convolve_kernel <- function(input, kernel, iter, scaling, bias) {
    .Call('_magick_magick_image_convolve_kernel', PACKAGE = 'magick', input, kernel, iter, scaling, bias)
}

magick_image_convolve_matrix <- function(input, matrix, iter, scaling, bias) {
    .Call('_magick_magick_image_convolve_matrix', PACKAGE = 'magick', input, matrix, iter, scaling, bias)
}

magick_device_internal <- function(bg, width, height, pointsize, res, clip, antialias, drawing) {
    .Call('_magick_magick_device_internal', PACKAGE = 'magick', bg, width, height, pointsize, res, clip, antialias, drawing)
}

magick_device_get <- function(n) {
    .Call('_magick_magick_device_get', PACKAGE = 'magick', n)
}

magick_device_pop <- function() {
    .Call('_magick_magick_device_pop', PACKAGE = 'magick')
}

magick_image_edge <- function(input, radius) {
    .Call('_magick_magick_image_edge', PACKAGE = 'magick', input, radius)
}

magick_image_canny <- function(input, geomstr) {
    .Call('_magick_magick_image_canny', PACKAGE = 'magick', input, geomstr)
}

magick_image_houghline <- function(input, geomstr, col, bg, lwd) {
    .Call('_magick_magick_image_houghline', PACKAGE = 'magick', input, geomstr, col, bg, lwd)
}

magick_image_readbitmap_native <- function(x) {
    .Call('_magick_magick_image_readbitmap_native', PACKAGE = 'magick', x)
}

magick_image_readbitmap_raster1 <- function(x) {
    .Call('_magick_magick_image_readbitmap_raster1', PACKAGE = 'magick', x)
}

magick_image_readbitmap_raster2 <- function(x) {
    .Call('_magick_magick_image_readbitmap_raster2', PACKAGE = 'magick', x)
}

magick_image_readbitmap_raw <- function(x) {
    .Call('_magick_magick_image_readbitmap_raw', PACKAGE = 'magick', x)
}

magick_image_readbitmap_double <- function(x) {
    .Call('_magick_magick_image_readbitmap_double', PACKAGE = 'magick', x)
}

magick_image_readbin <- function(x, density, depth, strip, defines) {
    .Call('_magick_magick_image_readbin', PACKAGE = 'magick', x, density, depth, strip, defines)
}

magick_image_readpath <- function(paths, density, depth, strip, defines) {
    .Call('_magick_magick_image_readpath', PACKAGE = 'magick', paths, density, depth, strip, defines)
}

magick_image_read_list <- function(list) {
    .Call('_magick_magick_image_read_list', PACKAGE = 'magick', list)
}

magick_image_write <- function(input, format, quality, depth, density, comment, compression) {
    .Call('_magick_magick_image_write', PACKAGE = 'magick', input, format, quality, depth, density, comment, compression)
}

magick_image_write_frame <- function(input, format, i = 1L) {
    .Call('_magick_magick_image_write_frame', PACKAGE = 'magick', input, format, i)
}

magick_image_write_integer <- function(input) {
    .Call('_magick_magick_image_write_integer', PACKAGE = 'magick', input)
}

magick_image_display <- function(image, animate) {
    .Call('_magick_magick_image_display', PACKAGE = 'magick', image, animate)
}

magick_image_fft <- function(image) {
    .Call('_magick_magick_image_fft', PACKAGE = 'magick', image)
}

magick_image_montage <- function(image, geometry, tile, gravity, bg = "white", shadow = FALSE) {
    .Call('_magick_magick_image_montage', PACKAGE = 'magick', image, geometry, tile, gravity, bg, shadow)
}

magick_image_strip <- function(input) {
    .Call('_magick_magick_image_strip', PACKAGE = 'magick', input)
}

magick_image_separate <- function(input, channel) {
    .Call('_magick_magick_image_separate', PACKAGE = 'magick', input, channel)
}

magick_image_combine <- function(input, colorspace, channel) {
    .Call('_magick_magick_image_combine', PACKAGE = 'magick', input, colorspace, channel)
}

magick_image_set_define <- function(input, format, name, value) {
    .Call('_magick_magick_image_set_define', PACKAGE = 'magick', input, format, name, value)
}

list_options <- function(str) {
    .Call('_magick_list_options', PACKAGE = 'magick', str)
}

set_magick_tempdir <- function(new_tmpdir) {
    .Call('_magick_set_magick_tempdir', PACKAGE = 'magick', new_tmpdir)
}

set_magick_seed <- function(seed) {
    invisible(.Call('_magick_set_magick_seed', PACKAGE = 'magick', seed))
}

magick_image_properties <- function(input) {
    .Call('_magick_magick_image_properties', PACKAGE = 'magick', input)
}

magick_image_scale <- function(input, geometry) {
    .Call('_magick_magick_image_scale', PACKAGE = 'magick', input, geometry)
}

magick_image_sample <- function(input, geometry) {
    .Call('_magick_magick_image_sample', PACKAGE = 'magick', input, geometry)
}

magick_image_resize <- function(input, geometry, filter) {
    .Call('_magick_magick_image_resize', PACKAGE = 'magick', input, geometry, filter)
}

magick_image_rotate <- function(input, degrees) {
    .Call('_magick_magick_image_rotate', PACKAGE = 'magick', input, degrees)
}

magick_image_chop <- function(input, geometry) {
    .Call('_magick_magick_image_chop', PACKAGE = 'magick', input, geometry)
}

magick_image_trim <- function(input, fuzz_percent) {
    .Call('_magick_magick_image_trim', PACKAGE = 'magick', input, fuzz_percent)
}

magick_image_flip <- function(input) {
    .Call('_magick_magick_image_flip', PACKAGE = 'magick', input)
}

magick_image_flop <- function(input) {
    .Call('_magick_magick_image_flop', PACKAGE = 'magick', input)
}

magick_image_shear <- function(input, geometry, color) {
    .Call('_magick_magick_image_shear', PACKAGE = 'magick', input, geometry, color)
}

magick_image_fuzzycmeans <- function(input, min_pixels = 1.0, smoothing = 1.5) {
    .Call('_magick_magick_image_fuzzycmeans', PACKAGE = 'magick', input, min_pixels, smoothing)
}

magick_image_connect <- function(input, connectivity = 4L) {
    .Call('_magick_magick_image_connect', PACKAGE = 'magick', input, connectivity)
}

magick_image_noise <- function(input, noisetype) {
    .Call('_magick_magick_image_noise', PACKAGE = 'magick', input, noisetype)
}

magick_image_blur <- function(input, radius = 1, sigma = 0.5) {
    .Call('_magick_magick_image_blur', PACKAGE = 'magick', input, radius, sigma)
}

magick_image_motion_blur <- function(input, radius = 1, sigma = 0.5, angle = 0.0) {
    .Call('_magick_magick_image_motion_blur', PACKAGE = 'magick', input, radius, sigma, angle)
}

magick_image_charcoal <- function(input, radius = 1, sigma = 0.5) {
    .Call('_magick_magick_image_charcoal', PACKAGE = 'magick', input, radius, sigma)
}

magick_image_deskew <- function(input, treshold) {
    .Call('_magick_magick_image_deskew', PACKAGE = 'magick', input, treshold)
}

magick_image_emboss <- function(input, radius = 1, sigma = 0.5) {
    .Call('_magick_magick_image_emboss', PACKAGE = 'magick', input, radius, sigma)
}

magick_image_fill <- function(input, color, point, fuzz_percent, border_color) {
    .Call('_magick_magick_image_fill', PACKAGE = 'magick', input, color, point, fuzz_percent, border_color)
}

magick_image_negate <- function(input) {
    .Call('_magick_magick_image_negate', PACKAGE = 'magick', input)
}

magick_image_oilpaint <- function(input, radius) {
    .Call('_magick_magick_image_oilpaint', PACKAGE = 'magick', input, radius)
}

magick_image_implode <- function(input, factor) {
    .Call('_magick_magick_image_implode', PACKAGE = 'magick', input, factor)
}

magick_image_format <- function(input, format, type, space, depth, antialias, matte, interlace) {
    .Call('_magick_magick_image_format', PACKAGE = 'magick', input, format, type, space, depth, antialias, matte, interlace)
}

magick_image_page <- function(input, pagesize, density) {
    .Call('_magick_magick_image_page', PACKAGE = 'magick', input, pagesize, density)
}

magick_image_repage <- function(input) {
    .Call('_magick_magick_image_repage', PACKAGE = 'magick', input)
}

magick_image_orient <- function(input, orientation) {
    .Call('_magick_magick_image_orient', PACKAGE = 'magick', input, orientation)
}

magick_image_despeckle <- function(input, times) {
    .Call('_magick_magick_image_despeckle', PACKAGE = 'magick', input, times)
}

magick_image_reducenoise <- function(input, radius) {
    .Call('_magick_magick_image_reducenoise', PACKAGE = 'magick', input, radius)
}

magick_image_annotate <- function(input, text, gravity, location, rot, size, font, style, weight, kerning, decoration, color, strokecolor, boxcolor) {
    .Call('_magick_magick_image_annotate', PACKAGE = 'magick', input, text, gravity, location, rot, size, font, style, weight, kerning, decoration, color, strokecolor, boxcolor)
}

magick_image_compare <- function(input, reference_image, metric, fuzz_percent) {
    .Call('_magick_magick_image_compare', PACKAGE = 'magick', input, reference_image, metric, fuzz_percent)
}

magick_image_distort <- function(input, method, values, bestfit) {
    .Call('_magick_magick_image_distort', PACKAGE = 'magick', input, method, values, bestfit)
}

